@@ -1,48 +1,57 @@
 var group__pw__node =
 [
+    [ "node.h", "src_2pipewire_2node_8h.html", null ],
     [ "pw_node_info", "structpw__node__info.html", [
-      [ "change_mask", "structpw__node__info.html#a88bcfe3c9dbce8c5c6ac7b663e4db009", null ],
-      [ "error", "structpw__node__info.html#a48075df9117cf8e55b474c8d2d445a1d", null ],
       [ "id", "structpw__node__info.html#a737754b76140ca4751f2cd68667ffaa2", null ],
       [ "max_input_ports", "structpw__node__info.html#a178dbb8570999efffa8584d13e52ce0e", null ],
       [ "max_output_ports", "structpw__node__info.html#ac312e1844784e77e412f6bb341814372", null ],
+      [ "change_mask", "structpw__node__info.html#a88bcfe3c9dbce8c5c6ac7b663e4db009", null ],
       [ "n_input_ports", "structpw__node__info.html#ae3b1789c08bcae95888e042790c95b75", null ],
       [ "n_output_ports", "structpw__node__info.html#ab5c2457030a463ccdc6ca5291ced856f", null ],
-      [ "n_params", "structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1", null ],
+      [ "state", "structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0", null ],
+      [ "error", "structpw__node__info.html#a48075df9117cf8e55b474c8d2d445a1d", null ],
       [ "params", "structpw__node__info.html#aa2bd90f2d1c5f570eac18709b2acc387", null ],
-      [ "props", "structpw__node__info.html#abc111c6b06e8564fd4a03854e109563b", null ],
-      [ "state", "structpw__node__info.html#a125f4d8851630b989c86fc0ebc83fba0", null ]
+      [ "n_params", "structpw__node__info.html#add4c3cdb14e0baa27c6c28d8c4a4d7f1", null ]
     ] ],
     [ "pw_node_events", "structpw__node__events.html", [
-      [ "info", "structpw__node__events.html#a9a6cdaf300007bc554b0c0b6bdbf5ccd", null ],
-      [ "param", "structpw__node__events.html#a07c012e13056aed56de654a44590df89", null ],
-      [ "version", "structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab", null ]
+      [ "version", "structpw__node__events.html#a37faf21db57a7e95999db521fb1cbcab", null ],
+      [ "info", "structpw__node__events.html#a31efa366284e12aa933c87ac63290adf", null ],
+      [ "param", "structpw__node__events.html#aa945ae608ff9a37d9fb0a2a24208caff", null ]
     ] ],
     [ "pw_node_methods", "structpw__node__methods.html", [
+      [ "version", "structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569", null ],
       [ "add_listener", "structpw__node__methods.html#a01dbc165d13370efdb6a54a5c3f40f41", null ],
-      [ "enum_params", "structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266", null ],
-      [ "send_command", "structpw__node__methods.html#a9f04049f6b62d408dacdefe1aafcc802", null ],
-      [ "set_param", "structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a", null ],
       [ "subscribe_params", "structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad", null ],
-      [ "version", "structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569", null ]
+      [ "enum_params", "structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266", null ],
+      [ "set_param", "structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a", null ],
+      [ "send_command", "structpw__node__methods.html#a9f04049f6b62d408dacdefe1aafcc802", null ]
     ] ],
-    [ "pw_node_add_listener", "group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3", null ],
-    [ "pw_node_enum_params", "group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f", null ],
-    [ "PW_NODE_EVENT_INFO", "group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813", null ],
-    [ "PW_NODE_EVENT_NUM", "group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4", null ],
-    [ "PW_NODE_EVENT_PARAM", "group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525", null ],
-    [ "pw_node_method", "group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b", null ],
-    [ "PW_NODE_METHOD_ADD_LISTENER", "group__pw__node.html#ga027e0d76dfb4448a29d718bec066b409", null ],
-    [ "PW_NODE_METHOD_ENUM_PARAMS", "group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40", null ],
-    [ "PW_NODE_METHOD_NUM", "group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35", null ],
-    [ "PW_NODE_METHOD_SEND_COMMAND", "group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090", null ],
-    [ "PW_NODE_METHOD_SET_PARAM", "group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730", null ],
-    [ "PW_NODE_METHOD_SUBSCRIBE_PARAMS", "group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8", null ],
-    [ "pw_node_send_command", "group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c", null ],
-    [ "pw_node_set_param", "group__pw__node.html#ga03964e24225bdf9a290590cd30ad664a", null ],
-    [ "pw_node_subscribe_params", "group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93", null ],
+    [ "pw_node", "structpw__node.html", null ],
     [ "PW_TYPE_INTERFACE_Node", "group__pw__node.html#ga125b3c8bae9656635dd9c24febbe221f", null ],
     [ "PW_VERSION_NODE", "group__pw__node.html#gae34dde148d3ae268808d68926a8a2da4", null ],
+    [ "PW_NODE_CHANGE_MASK_INPUT_PORTS", "group__pw__node.html#ga111891241c623bdfe86ba5e1811f374e", null ],
+    [ "PW_NODE_CHANGE_MASK_OUTPUT_PORTS", "group__pw__node.html#ga91a6a1a257b75f8a6fd5eb6755447a59", null ],
+    [ "PW_NODE_CHANGE_MASK_STATE", "group__pw__node.html#ga9d39e0829f4a14185dc242d5c362b9de", null ],
+    [ "PW_NODE_CHANGE_MASK_PROPS", "group__pw__node.html#ga3db541c9ec1c2245fe17402135979f2d", null ],
+    [ "PW_NODE_CHANGE_MASK_PARAMS", "group__pw__node.html#ga13f0cb22b45e8f81e709b84ff3b1fde7", null ],
+    [ "PW_NODE_CHANGE_MASK_ALL", "group__pw__node.html#ga7f79a67df47a08661d622c1ca73571ea", null ],
+    [ "PW_NODE_EVENT_INFO", "group__pw__node.html#gac3a4cf514e46d1e590ad45fd3e8d7813", null ],
+    [ "PW_NODE_EVENT_PARAM", "group__pw__node.html#gaf8cda535f0a1e63b1074f859cf650525", null ],
+    [ "PW_NODE_EVENT_NUM", "group__pw__node.html#ga3c78657690ffa3263238181bbe7073e4", null ],
+    [ "PW_VERSION_NODE_EVENTS", "group__pw__node.html#ga593a4f2610442e1956052f5c13de02f2", null ],
+    [ "PW_NODE_METHOD_ADD_LISTENER", "group__pw__node.html#ga027e0d76dfb4448a29d718bec066b409", null ],
+    [ "PW_NODE_METHOD_SUBSCRIBE_PARAMS", "group__pw__node.html#gaea23ddf2322c57e3cca4a7d40144bda8", null ],
+    [ "PW_NODE_METHOD_ENUM_PARAMS", "group__pw__node.html#ga5437fe007ac346f48f0f63fec8ca8b40", null ],
+    [ "PW_NODE_METHOD_SET_PARAM", "group__pw__node.html#ga6b2101857ce7cd58fa7024afa281a730", null ],
+    [ "PW_NODE_METHOD_SEND_COMMAND", "group__pw__node.html#ga3add61d46ad7b1daa86792cbeafc6090", null ],
+    [ "PW_NODE_METHOD_NUM", "group__pw__node.html#ga1977da2214d00db4a4d50202da3a2c35", null ],
+    [ "PW_VERSION_NODE_METHODS", "group__pw__node.html#ga0093e032db467e20f79767260fa1758e", null ],
+    [ "pw_node_method", "group__pw__node.html#ga8f11f362e3c9cda9d9fba69ed37f9c9b", null ],
+    [ "pw_node_add_listener", "group__pw__node.html#ga551b316bd8df6636cd863b82d3f006e3", null ],
+    [ "pw_node_subscribe_params", "group__pw__node.html#ga5768e66e04bfef45e468df3e38158c93", null ],
+    [ "pw_node_enum_params", "group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f", null ],
+    [ "pw_node_set_param", "group__pw__node.html#ga03964e24225bdf9a290590cd30ad664a", null ],
+    [ "pw_node_send_command", "group__pw__node.html#ga6ac60f95cc0fdb6d769df30cce34901c", null ],
     [ "pw_node_state", "group__pw__node.html#gac493839c0b0a1d0b935969f2e990a2df", [
       [ "PW_NODE_STATE_ERROR", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa316510257c8a6afc788c415cc3288ad2", null ],
       [ "PW_NODE_STATE_CREATING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa73a63afebf017a0c0afdea192b1691c", null ],
@@ -50,8 +59,8 @@ var group__pw__node =
       [ "PW_NODE_STATE_IDLE", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfa801ee69d0b0c9d30b12ff89daae9a075", null ],
       [ "PW_NODE_STATE_RUNNING", "group__pw__node.html#ggac493839c0b0a1d0b935969f2e990a2dfaa9c88f01497f82d9ffc4605dae27e93a", null ]
     ] ],
-    [ "pw_node_info_free", "group__pw__node.html#ga0ee148738da978c59c3afaf91215db71", null ],
-    [ "pw_node_info_merge", "group__pw__node.html#ga31e36ebfd9bbef91cea1381889a7cf83", null ],
+    [ "pw_node_state_as_string", "group__pw__node.html#gabdc61213ac88ea6daf6141e0130d0430", null ],
     [ "pw_node_info_update", "group__pw__node.html#ga98ac2a3a420d51c2afe18a0e79c18efe", null ],
-    [ "pw_node_state_as_string", "group__pw__node.html#gabdc61213ac88ea6daf6141e0130d0430", null ]
+    [ "pw_node_info_merge", "group__pw__node.html#ga31e36ebfd9bbef91cea1381889a7cf83", null ],
+    [ "pw_node_info_free", "group__pw__node.html#ga0ee148738da978c59c3afaf91215db71", null ]
 ];
\ No newline at end of file
