@@ -25,7 +25,13 @@
 var NAVTREE =
 [
   [ "PipeWire", "index.html", [
-    [ "Overview", "page_overview.html", null ],
+    [ "Components", "index.html#autotoc_md0", null ],
+    [ "API Documentation", "index.html#autotoc_md1", null ],
+    [ "More Documentation", "index.html#autotoc_md2", null ],
+    [ "Resources", "index.html#autotoc_md3", null ],
+    [ "Overview", "page_overview.html", [
+      [ "Motivation", "page_overview.html#autotoc_md4", null ]
+    ] ],
     [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
     [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
     [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
@@ -55,29 +61,30 @@ var NAVTREE =
 
 var NAVTREEINDEX =
 [
-"annotated.html",
-"globals_defs_p.html",
-"globals_l.html",
-"group__pw__context.html#gae01b3e37bd9c02da61ac4bad64dc7217",
-"group__pw__impl__link.html#ga8a9522e49aa17d076831c7e18026bc5a",
-"group__pw__link.html#gga7859f6eb040fead1673d0214b83b445ba1cdbf68b2f1a25b0c6202141e9069f70",
-"group__pw__port.html#gada3484ae34475c97571c091b7494d7b3",
-"group__pw__session__manager.html#gaa8366fa5903ce48d728d5a4bf1eb6ff2",
-"group__spa__ansi.html#gaad15091a1f40cc819dff1fc80374cc34",
-"group__spa__device.html#gacbe7c7131058a38cd357c7028387a1ff",
-"group__spa__log.html#ga57e9358ebf5d48ede482791857f234a8",
-"group__spa__node.html#gaed43186ba554d0253f721dda55ffe84d",
-"group__spa__param.html#gaee9165d1be224b58538dffab9ba90ba9",
-"group__spa__param.html#gga46887990fa9d119f5a5cdae12a985d81abf1fd7357ac7a7ad41615e4aee046731",
-"group__spa__param.html#ggacf6ba1ad0a715f691fcc3105cdffc30da3d42db97944bf4ee99d7d9c011a96302",
-"group__spa__pod.html#ga7c658bc2f25b9a3271292df883a16cd7",
-"group__spa__types.html#gaaaa70c8c33c359627dd29efe58e62503",
-"page_portal.html#autotoc_md39",
-"structpw__endpoint__info.html#a652272ff97cabdbc2cb630e631319894",
-"structpw__module__info.html#a027112b51093afc0ec6370a549bcb29f",
-"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560",
-"structspa__json.html#a8a0962e6aafa40f4b0124bcbb94e04df",
-"structspa__pod__string.html#aa7b8596a64741c1f0b728bc066643c79"
+"alloc_8h.html",
+"globals_defs_m.html",
+"globals_i.html",
+"group__pw__client__node.html#ga8f467593dff291edaac0f46531c23aed",
+"group__pw__impl__core.html#ga32f8301c7a43a4c4d418add1e71642a2",
+"group__pw__keys.html#gad7fe1ca68b65df33c09b8d14cfd708b0",
+"group__pw__permission.html#ga77df16320c3bb338666f55b2b21e6e47",
+"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
+"group__pwtest.html#gae28b2ed45d205b93298f6c85f9cf6913",
+"group__spa__device.html#ga0176aee6eac7ee89895ab4f4069afa41",
+"group__spa__keys.html#gab67f1f5fc3425c08a37874cbf7ac1afb",
+"group__spa__node.html#ga81ae3a5666e6a8b3b8236f8ff7749ea3",
+"group__spa__param.html#ga9c4f60adda447be6743c1cb662e4f915",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbca940b858de739418787236fd591abf505",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa308342b826a8580020b397f8d4281846",
+"group__spa__pod.html#ga3f71fd97eb4ca17b150a34bf05272307",
+"group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6",
+"module_8h.html",
+"page_streams.html#sec_create",
+"structpw__endpoint__link__events.html#ac358bf9f098e9a01690fb72901927427",
+"structpw__node.html",
+"structspa__buffer__alloc__info.html",
+"structspa__json.html#ae765edf5a3ac4c7fe5be87c93f62b0c2",
+"structspa__pod__struct.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
