@@ -1,5 +1,36 @@
 var NAVTREEINDEX16 =
 {
+"group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6":[10,8,8,11,10],
+"group__spa__string.html#gaccfedc485cb2e3bef649e77ee6db26ab":[10,8,8,11,1],
+"group__spa__string.html#gace4942742ce246641a3cb3b4b2540e05":[10,8,8,11,13],
+"group__spa__string.html#gae194d9bc956defbfe180dc658e3df052":[10,8,8,11,11],
+"group__spa__string.html#gae9be2db04a7f11c3ff07b78f635c9fe3":[10,8,8,11,16],
+"group__spa__support.html":[10,8,9],
+"group__spa__system.html":[10,8,9,7],
+"group__spa__system.html#ga0dd7ca3def67660ca1aa93c87f5d88a5":[10,8,9,7,15],
+"group__spa__system.html#ga1604e4f8d230b960c7bc30718297e86e":[10,8,9,7,37],
+"group__spa__system.html#ga282e1c96dc3c64fe48b01b93257191a3":[10,8,9,7,32],
+"group__spa__system.html#ga2dcb97fa874ae364a19ce37d7f7ed90f":[10,8,9,7,25],
+"group__spa__system.html#ga2e31883f569e32ad6dfcb52702d83014":[10,8,9,7,17],
+"group__spa__system.html#ga470bdc9dd5ec71d7f79bc893147420d0":[10,8,9,7,22],
+"group__spa__system.html#ga4afa9431eb60e1611908f1b984d17a22":[10,8,9,7,27],
+"group__spa__system.html#ga52bdd44fa6a91d7072ac43c994adc7be":[10,8,9,7,13],
+"group__spa__system.html#ga540f4b955fcdc5533291fea09de02348":[10,8,9,7,12],
+"group__spa__system.html#ga54a93b686738ba2115a8cac54202031f":[10,8,9,7,4],
+"group__spa__system.html#ga60a3b96114f829310a91613a9a84e7f5":[10,8,9,7,33],
+"group__spa__system.html#ga615390b2601f4551064d7bc5fec36737":[10,8,9,7,7],
+"group__spa__system.html#ga733abb5592ec21f4b66a6223255cdcbb":[10,8,9,7,11],
+"group__spa__system.html#ga8b0056bb9e3db8e8527bf8a83de48960":[10,8,9,7,35],
+"group__spa__system.html#ga971e2cf2384a6e07a3d0ed6bc8ed776d":[10,8,9,7,30],
+"group__spa__system.html#ga97e43c1810461311771e0eb3d34cbce5":[10,8,9,7,26],
+"group__spa__system.html#ga9a0a93bd110deace66ec7928965033ed":[10,8,9,7,21],
+"group__spa__system.html#gaab4122dc40f03111652545e70ee32b7c":[10,8,9,7,20],
+"group__spa__system.html#gac38f48e8f24186c07905b7905e921359":[10,8,9,7,36],
+"group__spa__system.html#gac69d59b92488f09f5facd97c39ef73a2":[10,8,9,7,10],
+"group__spa__system.html#gacac2b5413606eaa6c40a0ce2d037cb64":[10,8,9,7,16],
+"group__spa__system.html#gacf1a36b269e5c44bd0a44116fc1dff52":[10,8,9,7,31],
+"group__spa__system.html#gacfaeac3c65fa09b4974a79735520157f":[10,8,9,7,24],
+"group__spa__system.html#gad5262f91a3325573bc0cc0755bb00973":[10,8,9,7,9],
 "group__spa__system.html#gad8592bcc0072a7f3e01c1c599c31a59a":[10,8,9,7,6],
 "group__spa__system.html#gadc27e9cd52e02e882a9cff73cc39b84e":[10,8,9,7,5],
 "group__spa__system.html#gae3bdff54f3f6b5970f995d7dd1e0397a":[10,8,9,7,19],
@@ -105,149 +136,118 @@ var NAVTREEINDEX16 =
 "group__spa__utils.html":[10,8,8],
 "group__spa__utils__defs.html":[10,8,8,1],
 "group__spa__utils__defs.html#ga006941b3f6423cec7b170b4434d8a799":[10,8,8,1,8],
-"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[10,8,8,1,80],
-"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,55],
-"group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[10,8,8,1,19],
-"group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[10,8,8,1,24],
-"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[10,8,8,1,35],
-"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[10,8,8,1,54],
-"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[10,8,8,1,69],
-"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[10,8,8,1,63],
-"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[10,8,8,1,59],
-"group__spa__utils__defs.html#ga33e30c1bdbba747c8c00077913d48411":[10,8,8,1,21],
-"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[10,8,8,1,62],
-"group__spa__utils__defs.html#ga34890f84380ed041625fc0a252186bf2":[10,8,8,1,22],
-"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[10,8,8,1,77],
+"group__spa__utils__defs.html#ga007f98725701a4b6debe365c7a5e0bbe":[10,8,8,1,81],
+"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84":[10,8,8,1,56],
+"group__spa__utils__defs.html#ga06647c110a0382a09bea681a14634f64":[10,8,8,1,20],
+"group__spa__utils__defs.html#ga1179685eef5a041a5c8e60a9a6483048":[10,8,8,1,25],
+"group__spa__utils__defs.html#ga1b605788d4782d77eb54b75f258413b9":[10,8,8,1,36],
+"group__spa__utils__defs.html#ga1f57dfee056b657ddcd2bc69a7f45bce":[10,8,8,1,55],
+"group__spa__utils__defs.html#ga2157cfb3de1793302e5d08958bdc8ab2":[10,8,8,1,70],
+"group__spa__utils__defs.html#ga26f69327ba25a67c5120805511190740":[10,8,8,1,64],
+"group__spa__utils__defs.html#ga2c939bee0863eddd75b264b2aaf316e0":[10,8,8,1,60],
+"group__spa__utils__defs.html#ga33e30c1bdbba747c8c00077913d48411":[10,8,8,1,22],
+"group__spa__utils__defs.html#ga3404aa33acd9e8316fb33ebd146446f0":[10,8,8,1,63],
+"group__spa__utils__defs.html#ga34890f84380ed041625fc0a252186bf2":[10,8,8,1,23],
+"group__spa__utils__defs.html#ga3625c72ccb164919faaf2a3c5a37e9c2":[10,8,8,1,78],
 "group__spa__utils__defs.html#ga3bca1a11d1c7e8404f9456580acf0676":[10,8,8,1,10],
-"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,45],
-"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,57],
-"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,72],
-"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,65],
-"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,42],
+"group__spa__utils__defs.html#ga3d65c899d0f8937244ed2893d1841f6f":[10,8,8,1,46],
+"group__spa__utils__defs.html#ga3fecbba7e4f85f539f62c8db39f12b0a":[10,8,8,1,58],
+"group__spa__utils__defs.html#ga48e64fde9ece326caf683b04597614a5":[10,8,8,1,73],
+"group__spa__utils__defs.html#ga4a50fbd4b694e2826233b6d54ef3b5a8":[10,8,8,1,66],
+"group__spa__utils__defs.html#ga4a52677c41f0a787a3c6624f18647cb6":[10,8,8,1,43],
 "group__spa__utils__defs.html#ga57aec3d89182594c8fef7be284f41fff":[10,8,8,1,11],
 "group__spa__utils__defs.html#ga58dddf4d57e29beade3b44e156dea532":[10,8,8,1,15],
-"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[10,8,8,1,26],
-"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[10,8,8,1,28],
-"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[10,8,8,1,75],
-"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[10,8,8,1,39],
-"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[10,8,8,1,71],
-"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[10,8,8,1,40],
-"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[10,8,8,1,37],
+"group__spa__utils__defs.html#ga59196e4cfb0d8c0a8bdcd909cbbea334":[10,8,8,1,27],
+"group__spa__utils__defs.html#ga5b82642b5708ab665c9204338b6cd0e2":[10,8,8,1,61],
+"group__spa__utils__defs.html#ga5e46f399b745cda80c6a5a8ab8d5d14f":[10,8,8,1,29],
+"group__spa__utils__defs.html#ga6212956dcff36c69fa954f66efaefbcf":[10,8,8,1,76],
+"group__spa__utils__defs.html#ga6259b69a24b203050fe69cacac57748a":[10,8,8,1,40],
+"group__spa__utils__defs.html#ga632087e970399228667a768ba8424f4e":[10,8,8,1,72],
+"group__spa__utils__defs.html#ga6c2a22d6e106ac2f2d69d66a8ed35bd0":[10,8,8,1,41],
+"group__spa__utils__defs.html#ga6c3f9f95123f53da37d2bd173bd17ed1":[10,8,8,1,38],
 "group__spa__utils__defs.html#ga796e3d4570d8d539ea5886074a646a11":[10,8,8,1,16],
-"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[10,8,8,1,46],
-"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[10,8,8,1,38],
-"group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[10,8,8,1,23],
+"group__spa__utils__defs.html#ga7b184a799c7168d95deaecab5208f557":[10,8,8,1,47],
+"group__spa__utils__defs.html#ga7b3174639eb92d4c045a2bbc72a035df":[10,8,8,1,39],
+"group__spa__utils__defs.html#ga7f23cca5e034297bbd1b6860d1dbfdbc":[10,8,8,1,24],
 "group__spa__utils__defs.html#ga895eccfd8032e0e9eec102e3b8442f12":[10,8,8,1,17],
-"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[10,8,8,1,51],
-"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[10,8,8,1,66],
-"group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[10,8,8,1,81],
-"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[10,8,8,1,70],
-"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[10,8,8,1,68],
+"group__spa__utils__defs.html#ga933e7dba5e09dd618617b7b16c0d42fc":[10,8,8,1,52],
+"group__spa__utils__defs.html#ga9a615b131c891caac9a73e05b35da09c":[10,8,8,1,67],
+"group__spa__utils__defs.html#ga9f2fae4a58cc2e3fdf568d1afc9dc7c1":[10,8,8,1,82],
+"group__spa__utils__defs.html#gaa360562916c7e9ab66865f277477f4e6":[10,8,8,1,71],
+"group__spa__utils__defs.html#gaa3a2b836ca54d95f207f5557988db748":[10,8,8,1,69],
 "group__spa__utils__defs.html#gaa44a69e371d934ab026ae08af1d9b67e":[10,8,8,1,7],
-"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[10,8,8,1,29],
-"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[10,8,8,1,33],
-"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[10,8,8,1,36],
-"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[10,8,8,1,27],
-"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[10,8,8,1,48],
-"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[10,8,8,1,64],
-"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[10,8,8,1,61],
-"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[10,8,8,1,52],
-"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[10,8,8,1,67],
-"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[10,8,8,1,31],
-"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[10,8,8,1,50],
-"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[10,8,8,1,49],
+"group__spa__utils__defs.html#gaa495b586c261831b67f09c7f9851aa05":[10,8,8,1,30],
+"group__spa__utils__defs.html#gaa92b4913ce779aa401cc714ae829eace":[10,8,8,1,34],
+"group__spa__utils__defs.html#gaabdb5fd45bca56878896d7c28204fb88":[10,8,8,1,37],
+"group__spa__utils__defs.html#gaad6949f0b0a59d29fdf35ff11ebf83cb":[10,8,8,1,28],
+"group__spa__utils__defs.html#gab30712bed8289c9218eb66d9bfeeab78":[10,8,8,1,49],
+"group__spa__utils__defs.html#gab4c957beedd4012fd0513f174d7b8b1a":[10,8,8,1,65],
+"group__spa__utils__defs.html#gabfdffcb3a4e4e4a488a2ff714e01b3ca":[10,8,8,1,62],
+"group__spa__utils__defs.html#gac1ac8f034b73e453c531d928cdfdd8b7":[10,8,8,1,53],
+"group__spa__utils__defs.html#gac30327f8b5e6a9c6f9129a73581d09dc":[10,8,8,1,68],
+"group__spa__utils__defs.html#gac8080acabcd35c560a15df5e1801afa1":[10,8,8,1,32],
+"group__spa__utils__defs.html#gac894bd2d39b2644e1bacf4b11c0a187d":[10,8,8,1,51],
+"group__spa__utils__defs.html#gac8965bea56eb75da08e84a547bee992e":[10,8,8,1,50],
 "group__spa__utils__defs.html#gacbdd2b8d9e9137bbbd9a38f495c80263":[10,8,8,1,5],
-"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[10,8,8,1,43],
+"group__spa__utils__defs.html#gacc9914448bc9fd68ae5ccf004c401bcb":[10,8,8,1,44],
 "group__spa__utils__defs.html#gace48f5bc6836a62c328fcac938f8ea6e":[10,8,8,1,14],
 "group__spa__utils__defs.html#gaceee1eb1469c2ab68034f5619913bc0d":[10,8,8,1,9],
-"group__spa__utils__defs.html#gad199e69d5c112451d5a1abf07b9e0b8b":[10,8,8,1,60],
-"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[10,8,8,1,53],
-"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[10,8,8,1,44],
-"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[10,8,8,1,58],
-"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[10,8,8,1,78],
-"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[10,8,8,1,76],
-"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[10,8,8,1,25],
-"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[10,8,8,1,73],
-"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[10,8,8,1,30],
+"group__spa__utils__defs.html#gad485e752b9b897f6434724f669ba72ae":[10,8,8,1,54],
+"group__spa__utils__defs.html#gad5b23b2094b330aacd6489da1c8fa7b7":[10,8,8,1,45],
+"group__spa__utils__defs.html#gadc0cd747e27d01b74cdd6d3131e3df27":[10,8,8,1,59],
+"group__spa__utils__defs.html#gadd03b1b1f299d9249de66ff32bc34569":[10,8,8,1,79],
+"group__spa__utils__defs.html#gae1bb114e5bb79da44be5c26e7a9bf6e1":[10,8,8,1,18],
+"group__spa__utils__defs.html#gae2c26bfcbc2a33bcfae86018b35fab20":[10,8,8,1,77],
+"group__spa__utils__defs.html#gae8ab0b793d870a9725897e695454c12b":[10,8,8,1,26],
+"group__spa__utils__defs.html#gae8d35b670e70b6cdba489ca76b5791d4":[10,8,8,1,74],
+"group__spa__utils__defs.html#gaec22d2ead4ec1771760219dc16f24709":[10,8,8,1,31],
 "group__spa__utils__defs.html#gaf296ce57d6de2645675d2c89fdc8af0a":[10,8,8,1,6],
 "group__spa__utils__defs.html#gaf42b2cfc208dc17d25624d84f962b25d":[10,8,8,1,13],
-"group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[10,8,8,1,18],
-"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[10,8,8,1,79],
-"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[10,8,8,1,56],
-"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[10,8,8,1,34],
-"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[10,8,8,1,41],
-"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[10,8,8,1,74],
-"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[10,8,8,1,32],
-"group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[10,8,8,1,20],
-"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[10,8,8,1,47],
+"group__spa__utils__defs.html#gaf5c3a152070995c325caaaf0333269c0":[10,8,8,1,19],
+"group__spa__utils__defs.html#gaf7a3ad1f0f015a14f7719022fc6e5a0e":[10,8,8,1,80],
+"group__spa__utils__defs.html#gaf88c39fbcce246ddc0e78a934dda87cb":[10,8,8,1,57],
+"group__spa__utils__defs.html#gaf8cdb131feb79dfd1d9d1097cb89c052":[10,8,8,1,35],
+"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[10,8,8,1,42],
+"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[10,8,8,1,75],
+"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[10,8,8,1,33],
+"group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[10,8,8,1,21],
+"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[10,8,8,1,48],
 "group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[10,8,8,1,12],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,81,0],
-"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,81,1],
+"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[10,8,8,1,82,0],
+"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[10,8,8,1,82,1],
+"hook_8h.html":[10,8,8,4,0],
+"hook_8h.html":[10,8,8,5,0],
+"iec958_8h.html":[10,8,7,2],
+"impl-client_8h.html":[10,5,0,0],
+"impl-core_8h.html":[10,5,1,0],
+"impl-device_8h.html":[10,5,2,0],
+"impl-factory_8h.html":[10,5,3,0],
+"impl-interfaces_8h.html":[10,7,4,1],
+"impl-link_8h.html":[10,5,4,0],
+"impl-metadata_8h.html":[10,5,5,0],
+"impl-module_8h.html":[10,5,6,0],
+"impl-node_8h.html":[10,5,7,0],
+"impl-port_8h.html":[10,5,8,0],
+"impl_8h.html":[10,5,17],
 "index.html":[],
 "index.html#autotoc_md0":[0],
 "index.html#autotoc_md1":[1],
 "index.html#autotoc_md2":[2],
 "index.html#autotoc_md3":[3],
+"interfaces_8h.html":[10,7,4,2],
+"introspect-funcs_8h.html":[10,7,4,4],
+"introspect_8h.html":[10,7,4,3],
+"io_8h.html":[10,8,6,2],
+"iter_8h.html":[10,8,0,5],
+"json-pod_8h.html":[10,3,0],
+"json_8h.html":[10,8,8,6,0],
+"layout_8h.html":[10,8,7,3],
+"link_8h.html":[10,4,7,0],
+"list_8h.html":[10,8,8,3,0],
 "local-v4l2_8c-example.html":[13,24],
-"modules.html":[10],
-"page_access.html":[5,5],
-"page_access.html#autotoc_md10":[5,5,0],
-"page_access.html#autotoc_md11":[5,5,0,0],
-"page_access.html#autotoc_md12":[5,5,0,1],
-"page_access.html#autotoc_md13":[5,5,0,2],
-"page_access.html#autotoc_md14":[5,5,0,3],
-"page_access.html#autotoc_md15":[5,5,0,4],
-"page_access.html#autotoc_md16":[5,5,1],
-"page_access.html#autotoc_md17":[5,5,1,0],
-"page_access.html#autotoc_md18":[5,5,1,1],
-"page_access.html#autotoc_md19":[5,5,1,2],
-"page_api.html":[8],
-"page_audio.html":[5,4],
-"page_audio.html#autotoc_md100":[5,4,0,5],
-"page_audio.html#autotoc_md101":[5,4,0,6],
-"page_audio.html#autotoc_md102":[5,4,1],
-"page_audio.html#autotoc_md103":[5,4,1,0],
-"page_audio.html#autotoc_md104":[5,4,1,1],
-"page_audio.html#autotoc_md105":[5,4,1,2],
-"page_audio.html#autotoc_md106":[5,4,2],
-"page_audio.html#autotoc_md107":[5,4,2,0],
-"page_audio.html#autotoc_md94":[5,4,0],
-"page_audio.html#autotoc_md95":[5,4,0,0],
-"page_audio.html#autotoc_md96":[5,4,0,1],
-"page_audio.html#autotoc_md97":[5,4,0,2],
-"page_audio.html#autotoc_md98":[5,4,0,3],
-"page_audio.html#autotoc_md99":[5,4,0,4],
-"page_client_impl.html":[8,0],
-"page_client_impl.html#sec_page_client_impl_credentials":[8,0,1],
-"page_client_impl.html#sec_page_client_impl_overview":[8,0,0],
-"page_client_impl.html#sec_page_client_impl_resources":[8,0,3],
-"page_client_impl.html#sec_page_client_impl_types":[8,0,2],
-"page_daemon.html":[5,11],
-"page_daemon.html#autotoc_md42":[5,11,0],
-"page_daemon.html#autotoc_md43":[5,11,0,0],
-"page_daemon.html#autotoc_md44":[5,11,1],
-"page_design.html":[5,3],
-"page_design.html#autotoc_md8":[5,3,0],
-"page_design.html#autotoc_md9":[5,3,1],
-"page_dma_buf.html":[5,10],
-"page_dma_buf.html#autotoc_md157":[5,10,0],
-"page_dma_buf.html#autotoc_md158":[5,10,0,0],
-"page_dma_buf.html#autotoc_md159":[5,10,0,1],
-"page_dma_buf.html#autotoc_md160":[5,10,0,1,0],
-"page_dma_buf.html#autotoc_md161":[5,10,0,1,1],
-"page_dma_buf.html#autotoc_md162":[5,10,0,2],
-"page_dma_buf.html#autotoc_md163":[5,10,0,3],
-"page_dma_buf.html#autotoc_md164":[5,10,0,4],
-"page_dma_buf.html#autotoc_md165":[5,10,1],
-"page_dma_buf.html#autotoc_md166":[5,10,2],
-"page_dma_buf.html#autotoc_md167":[5,10,3],
-"page_examples.html":[7,7],
-"page_library.html":[5,9],
-"page_library.html#autotoc_md45":[5,9,0],
-"page_library.html#autotoc_md46":[5,9,1],
-"page_library.html#autotoc_md47":[5,9,2],
-"page_library.html#autotoc_md48":[5,9,3],
-"page_library.html#autotoc_md49":[5,9,3,0],
-"page_library.html#autotoc_md50":[5,9,3,1],
-"page_library.html#autotoc_md51":[5,9,3,2]
+"log-impl_8h.html":[10,8,9,3,0],
+"main-loop_8h.html":[10,4,1,0],
+"map_8h.html":[10,6,4,0],
+"meta_8h.html":[10,8,1,2],
+"metadata_8h.html":[10,7,1,0]
 };
